@@ -1,14 +1,14 @@
 package Date::Holidays::Adapter::USA;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: DEPRECATED - Adapter for USA holidays
+# ABSTRACT: Adapter for USA holidays
 
 use strict;
 use warnings;
 
 use base qw(Date::Holidays::Adapter);
 
-our $VERSION = '0.0109_1';
+our $VERSION = '0.0100';
 
 
 
@@ -47,16 +47,16 @@ __END__
 
 =head1 NAME
 
-Date::Holidays::Adapter::USA - DEPRECATED - Adapter for USA holidays
+Date::Holidays::Adapter::USA - Adapter for USA holidays
 
 =head1 VERSION
 
-version 0.0109_1
+version 0.0100
 
 =head1 DESCRIPTION
 
-C<Date::Holidays::Adapter::USA> is now deprecated, but was the
-L<Date::Holidays> adapter for L<Date::Holidays::USA>.
+C<Date::Holidays::Adapter::USA> is the L<Date::Holidays> adapter for
+L<Date::Holidays::USA>.
 
 =head1 FUNCTIONS
 
